@@ -4,7 +4,7 @@
 #' "Global maps of twenty-first century forest carbon fluxes.". It
 #' represents "the greenhouse gas
 #' emissions arising from stand-replacing forest disturbances that occurred in
-#' each modeled year (megagrams CO2 emissions/ha, between 2001 and 2020).
+#' each modelled year (megagrams CO2 emissions/ha, between 2001 and 2020).
 #' Emissions include all relevant ecosystem carbon pools (aboveground biomass,
 #' belowground biomass, dead wood, litter, soil) and greenhouse gases (CO2, CH4,
 #' N2O)." The area unit that is downloaded here corresponds to the
@@ -41,7 +41,7 @@ NULL
 
   index_file <- system.file("extdata", "greenhouse_index.geosjon", package = "mapme.biodiversity")
   spatialindex <- st_read(index_file, quiet = TRUE)
-  tile_ids <- unlist(st_intersects(x, spatialindex))
+  tile_ids <- unique(unlist(st_intersects(x, spatialindex)))
   tile_ids <- spatialindex$tile_id[tile_ids]
   urls <- as.character(
     spatialindex$Mg_CO2e_px_download[spatialindex$tile_id %in% tile_ids]
