@@ -1,4 +1,5 @@
 test_that("init_portfolio works", {
+  options(pillar.advice = FALSE)
   aoi <- read_sf(
     system.file("extdata", "sierra_de_neiba_478140.gpkg",
                 package = "mapme.biodiversity"
@@ -123,11 +124,11 @@ test_that("init_portfolio works", {
                               cores = 1,
                               verbose = FALSE,
                               add_resources = FALSE) %>%
-    get_resources(c("treecover2000", "lossyear"),
+    get_resources(c("gfw_treecover", "gfw_lossyear"),
                   vers_lossyear = "GFC-2020-v1.8", vers_treecover = "GFC-2020-v1.8")
 
   tmpfile <- file.path(file.path(tempdir(), "portfolio_out.gpkg"))
-  portfolio <- calc_indicators(portfolio, "treecover", min_size = 1, min_cover = 30)
+  portfolio <- calc_indicators(portfolio, "treecover_area", min_size = 1, min_cover = 30)
 
   expect_invisible(
     write_portfolio(portfolio, tmpfile, quiet = TRUE)
